@@ -517,33 +517,28 @@ bgp_damp_disable (struct bgp *bgp, afi_t afi, safi_t safi)
   return 0;
 }
 
-int
+void
 bgp_config_write_damp (struct vty *vty)
 {
-  if (&bgp_damp_cfg)
-    {
-      if (bgp_damp_cfg.half_life == DEFAULT_HALF_LIFE*60
-	  && bgp_damp_cfg.reuse_limit == DEFAULT_REUSE
-	  && bgp_damp_cfg.suppress_value == DEFAULT_SUPPRESS
-	  && bgp_damp_cfg.max_suppress_time == bgp_damp_cfg.half_life*4)
-	vty_out (vty, " bgp dampening%s", VTY_NEWLINE);
-      else if (bgp_damp_cfg.half_life != DEFAULT_HALF_LIFE*60
-	       && bgp_damp_cfg.reuse_limit == DEFAULT_REUSE
-	       && bgp_damp_cfg.suppress_value == DEFAULT_SUPPRESS
-	       && bgp_damp_cfg.max_suppress_time == bgp_damp_cfg.half_life*4)
-	vty_out (vty, " bgp dampening %ld%s",
-		 bgp_damp_cfg.half_life/60,
-		 VTY_NEWLINE);
-      else
-	vty_out (vty, " bgp dampening %ld %d %d %ld%s",
-		 bgp_damp_cfg.half_life/60,
-		 bgp_damp_cfg.reuse_limit,
-		 bgp_damp_cfg.suppress_value,
-		 bgp_damp_cfg.max_suppress_time/60,
-		 VTY_NEWLINE);
-      return 1;
-    }
-  return 0;
+  if (bgp_damp_cfg.half_life == DEFAULT_HALF_LIFE*60
+      && bgp_damp_cfg.reuse_limit == DEFAULT_REUSE
+      && bgp_damp_cfg.suppress_value == DEFAULT_SUPPRESS
+      && bgp_damp_cfg.max_suppress_time == bgp_damp_cfg.half_life*4)
+    vty_out (vty, " bgp dampening%s", VTY_NEWLINE);
+  else if (bgp_damp_cfg.half_life != DEFAULT_HALF_LIFE*60
+	   && bgp_damp_cfg.reuse_limit == DEFAULT_REUSE
+	   && bgp_damp_cfg.suppress_value == DEFAULT_SUPPRESS
+	   && bgp_damp_cfg.max_suppress_time == bgp_damp_cfg.half_life*4)
+    vty_out (vty, " bgp dampening %ld%s",
+	     bgp_damp_cfg.half_life/60,
+	     VTY_NEWLINE);
+  else
+    vty_out (vty, " bgp dampening %ld %d %d %ld%s",
+	     bgp_damp_cfg.half_life/60,
+	     bgp_damp_cfg.reuse_limit,
+	     bgp_damp_cfg.suppress_value,
+	     bgp_damp_cfg.max_suppress_time/60,
+	     VTY_NEWLINE);
 }
 
 #define BGP_UPTIME_LEN 25
