@@ -50,11 +50,6 @@
 
 char ospf6_daemon_version[] = OSPF6_DAEMON_VERSION;
 
-void
-ospf6_debug ()
-{
-}
-
 struct route_node *
 route_prev (struct route_node *node)
 {
@@ -104,7 +99,7 @@ struct cmd_node debug_node =
   1 /* VTYSH */
 };
 
-int
+static int
 config_write_ospf6_debug (struct vty *vty)
 {
   config_write_ospf6_debug_message (vty);
@@ -221,7 +216,7 @@ ALIAS (show_ipv6_ospf6_database,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_type,
        show_ipv6_ospf6_database_type_cmd,
@@ -315,7 +310,7 @@ ALIAS (show_ipv6_ospf6_database_type,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_id,
        show_ipv6_ospf6_database_id_cmd,
@@ -384,7 +379,7 @@ ALIAS (show_ipv6_ospf6_database_id,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 ALIAS (show_ipv6_ospf6_database_id,
        show_ipv6_ospf6_database_linkstate_id_cmd,
@@ -395,7 +390,7 @@ ALIAS (show_ipv6_ospf6_database_id,
        "Display Link state database\n"
        "Search by Link state ID\n"
        "Specify Link state ID as IPv4 address notation\n"
-      );
+      )
 
 ALIAS (show_ipv6_ospf6_database_id,
        show_ipv6_ospf6_database_linkstate_id_detail_cmd,
@@ -410,7 +405,7 @@ ALIAS (show_ipv6_ospf6_database_id,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_router,
        show_ipv6_ospf6_database_router_cmd,
@@ -481,7 +476,7 @@ ALIAS (show_ipv6_ospf6_database_router,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 ALIAS (show_ipv6_ospf6_database_router,
        show_ipv6_ospf6_database_adv_router_cmd,
@@ -492,7 +487,7 @@ ALIAS (show_ipv6_ospf6_database_router,
        "Display Link state database\n"
        "Search by Advertising Router\n"
        "Specify Advertising Router as IPv4 address notation\n"
-      );
+      )
 
 ALIAS (show_ipv6_ospf6_database_router,
        show_ipv6_ospf6_database_adv_router_detail_cmd,
@@ -507,7 +502,7 @@ ALIAS (show_ipv6_ospf6_database_router,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_type_id,
        show_ipv6_ospf6_database_type_id_cmd,
@@ -614,7 +609,7 @@ ALIAS (show_ipv6_ospf6_database_type_id,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 ALIAS (show_ipv6_ospf6_database_type_id,
        show_ipv6_ospf6_database_type_linkstate_id_cmd,
@@ -636,7 +631,7 @@ ALIAS (show_ipv6_ospf6_database_type_id,
        "Display Intra-Area-Prefix LSAs\n"
        "Search by Link state ID\n"
        "Specify Link state ID as IPv4 address notation\n"
-      );
+      )
 
 ALIAS (show_ipv6_ospf6_database_type_id,
        show_ipv6_ospf6_database_type_linkstate_id_detail_cmd,
@@ -662,7 +657,7 @@ ALIAS (show_ipv6_ospf6_database_type_id,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_type_router,
        show_ipv6_ospf6_database_type_router_cmd,
@@ -771,7 +766,7 @@ ALIAS (show_ipv6_ospf6_database_type_router,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 ALIAS (show_ipv6_ospf6_database_type_router,
        show_ipv6_ospf6_database_type_adv_router_cmd,
@@ -793,7 +788,7 @@ ALIAS (show_ipv6_ospf6_database_type_router,
        "Display Intra-Area-Prefix LSAs\n"
        "Search by Advertising Router\n"
        "Specify Advertising Router as IPv4 address notation\n"
-      );
+      )
 
 ALIAS (show_ipv6_ospf6_database_type_router,
        show_ipv6_ospf6_database_type_adv_router_detail_cmd,
@@ -819,7 +814,7 @@ ALIAS (show_ipv6_ospf6_database_type_router,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_id_router,
        show_ipv6_ospf6_database_id_router_cmd,
@@ -901,7 +896,7 @@ ALIAS (show_ipv6_ospf6_database_id_router,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_adv_router_linkstate_id,
        show_ipv6_ospf6_database_adv_router_linkstate_id_cmd,
@@ -985,7 +980,7 @@ ALIAS (show_ipv6_ospf6_database_adv_router_linkstate_id,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_type_id_router,
        show_ipv6_ospf6_database_type_id_router_cmd,
@@ -1104,7 +1099,7 @@ ALIAS (show_ipv6_ospf6_database_type_id_router,
        "Specify Advertising Router as IPv4 address notation\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_type_adv_router_linkstate_id,
        show_ipv6_ospf6_database_type_adv_router_linkstate_id_cmd,
@@ -1229,7 +1224,7 @@ ALIAS (show_ipv6_ospf6_database_type_adv_router_linkstate_id,
        "Specify Link state ID as IPv4 address notation\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_self_originated,
        show_ipv6_ospf6_database_self_originated_cmd,
@@ -1386,7 +1381,7 @@ ALIAS (show_ipv6_ospf6_database_type_self_originated,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_type_self_originated_linkstate_id,
        show_ipv6_ospf6_database_type_self_originated_linkstate_id_cmd,
@@ -1501,7 +1496,7 @@ ALIAS (show_ipv6_ospf6_database_type_self_originated_linkstate_id,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_database_type_id_self_originated,
        show_ipv6_ospf6_database_type_id_self_originated_cmd,
@@ -1614,7 +1609,7 @@ ALIAS (show_ipv6_ospf6_database_type_id_self_originated,
        "Display details of LSAs\n"
        "Dump LSAs\n"
        "Display LSA's internal information\n"
-      );
+      )
 
 
 DEFUN (show_ipv6_ospf6_border_routers,
@@ -1675,7 +1670,7 @@ ALIAS (show_ipv6_ospf6_border_routers,
        "Display routing table for ABR and ASBR\n"
        "Specify Router-ID\n"
        "Display Detail\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_linkstate,
        show_ipv6_ospf6_linkstate_cmd,
@@ -1709,7 +1704,7 @@ ALIAS (show_ipv6_ospf6_linkstate,
        "Display linkstate routing table\n"
        "Display Router Entry\n"
        "Specify Router ID as IPv4 address notation\n"
-      );
+      )
 
 ALIAS (show_ipv6_ospf6_linkstate,
        show_ipv6_ospf6_linkstate_network_cmd,
@@ -1721,7 +1716,7 @@ ALIAS (show_ipv6_ospf6_linkstate,
        "Display Network Entry\n"
        "Specify Router ID as IPv4 address notation\n"
        "Specify Link state ID as IPv4 address notation\n"
-      );
+      )
 
 DEFUN (show_ipv6_ospf6_linkstate_detail,
        show_ipv6_ospf6_linkstate_detail_cmd,
@@ -1757,7 +1752,7 @@ DEFUN (show_ipv6_ospf6_linkstate_detail,
 
 /* Install ospf related commands. */
 void
-ospf6_init ()
+ospf6_init (void)
 {
   ospf6_top_init ();
   ospf6_area_init ();
