@@ -47,7 +47,6 @@ struct zebra_t zebrad =
 };
 
 /* process id. */
-pid_t old_pid;
 pid_t pid;
 
 /* Pacify zclient.o in libzebra, which expects this variable. */
@@ -276,7 +275,8 @@ main (int argc, char **argv)
 	      break;
 	    } 
 	  vty_port = atoi (optarg);
-	  vty_port = (vty_port ? vty_port : ZEBRA_VTY_PORT);
+	  if (vty_port <= 0 || vty_port > 0xffff)
+	    vty_port = ZEBRA_VTY_PORT;
 	  break;
 	case 'r':
 	  retain_mode = 1;
@@ -346,11 +346,13 @@ main (int argc, char **argv)
   zebra_snmp_init ();
 #endif /* HAVE_SNMP */
 
-  /* Clean up self inserted route. */
-  if (! keep_kernel_mode)
-    rib_sweep_route ();
-
-  /* Configuration file read*/
+  /* Process the configuration file. Among other configuration
+  *  directives we can meet those installing static routes. Such
+  *  requests will not be executed immediately, but queued in
+  *  zebra->ribq structure until we enter the main execution loop.
+  *  The notifications from kernel will show originating PID equal
+  *  to that after daemon() completes (if ever called).
+  */
   vty_read_config (config_file, config_default);
 
   /* Don't start execution if we are in dry-run mode */
@@ -364,9 +366,6 @@ main (int argc, char **argv)
   if (batch_mode)
     exit (0);
 
-  /* Needed for BSD routing socket. */
-  old_pid = getpid ();
-
   /* Daemonize. */
   if (daemon_mode)
     daemon (0, 0);
@@ -374,6 +373,17 @@ main (int argc, char **argv)
   /* Output pid of zebra. */
   pid_output (pid_file);
 
+  /* After we have successfully acquired the pidfile, we can be sure
+  *  about being the only copy of zebra process, which is submitting
+  *  changes to the FIB.
+  *  Clean up zebra-originated routes. The requests will be sent to OS
+  *  immediately, so originating PID in notifications from kernel
+  *  will be equal to the current getpid(). To know about such routes,
+  * we have to have route_read() called before.
+  */
+  if (! keep_kernel_mode)
+    rib_sweep_route ();
+
   /* Needed for BSD routing socket. */
   pid = getpid ();
 
